@@ -5,8 +5,6 @@
  *
  * Part:        Healthcheckrs child process handling.
  *
- * Version:     $Id: check_daemon.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "check_daemon.h"
@@ -124,49 +122,22 @@ start_check(void)
 		dump_check_data(check_data);
 	}
 
+#ifdef _WITH_VRRP_
+	/* Initialize linkbeat */
+	init_interface_linkbeat();
+#endif
+
 	/* Register checkers thread */
 	register_checkers_thread();
 }
 
 /* Reload handler */
-int
-reload_check_thread(thread * thread_obj)
-{
-	/* set the reloading flag */
-	SET_RELOAD;
-
-	/* Destroy master thread */
-	thread_destroy_master(master);
-	master = thread_make_master();
-	free_global_data(data);
-	free_checkers_queue();
-#ifdef _WITH_VRRP_
-	free_interface_queue();
-#endif
-	free_ssl();
-	ipvs_stop();
-
-	/* Save previous conf data */
-	old_check_data = check_data;
-	check_data = NULL;
-
-	/* Reload the conf */
-	mem_allocated = 0;
-	start_check();
-
-	/* free backup data */
-	free_check_data(old_check_data);
-	UNSET_RELOAD;
-
-	return 0;
-}
-
-/* Reload handler */
+int reload_check_thread(thread * thread_obj);
 void
 sighup_check(void *v, int sig)
 {
-	log_message(LOG_INFO, "Reloading Healthchecker child processi(%d) on signal",
-	       checkers_child);
+	log_message(LOG_INFO, "Reloading Healthchecker child process(%d) on signal",
+		    getpid());
 	thread_add_event(master, reload_check_thread, NULL, 0);
 }
 
@@ -190,6 +161,45 @@ check_signal_init(void)
 	signal_ignore(SIGPIPE);
 }
 
+/* Reload thread */
+int
+reload_check_thread(thread * thread_obj)
+{
+	/* set the reloading flag */
+	SET_RELOAD;
+
+	/* Signals handling */
+	signal_reset();
+	signal_handler_destroy();
+
+	/* Destroy master thread */
+	thread_destroy_master(master);
+	master = thread_make_master();
+	free_global_data(data);
+	free_checkers_queue();
+#ifdef _WITH_VRRP_
+	free_interface_queue();
+#endif
+	free_ssl();
+	ipvs_stop();
+
+	/* Save previous conf data */
+	old_check_data = check_data;
+	check_data = NULL;
+
+	/* Reload the conf */
+	mem_allocated = 0;
+	check_signal_init();
+	signal_set(SIGCHLD, thread_child_handler, master);
+	start_check();
+
+	/* free backup data */
+	free_check_data(old_check_data);
+	UNSET_RELOAD;
+
+	return 0;
+}
+
 /* CHECK Child respawning thread */
 int
 check_respawn_thread(thread * thread_obj)
@@ -216,15 +226,10 @@ check_respawn_thread(thread * thread_obj)
 int
 start_check_child(void)
 {
-	pid_t pid;
-
-	/* Dont start if pid is already running */
-	if (checkers_running()) {
-		log_message(LOG_INFO, "Healthcheck child process already running");
-		return -1;
-	}
-
 #ifndef _DEBUG_
+	pid_t pid;
+	int ret;
+
 	/* Initialize child process */
 	pid = fork();
 
@@ -259,12 +264,17 @@ start_check_child(void)
 	master = thread_make_master();
 
 	/* change to / dir */
-	chdir("/");
+	ret = chdir("/");
 
 	/* Set mask */
 	umask(0);
 #endif
 
+	/* If last process died during a reload, we can get there and we
+	 * don't want to loop again, because we're not reloading anymore.
+	 */
+	UNSET_RELOAD;
+
 	/* Signal handling initialization */
 	check_signal_init();
 
