@@ -6,8 +6,6 @@
  * Part:        MISC CHECK. Perform a system call to run an extra
  *              system prog or script.
  *
- * Version:     $Id: check_misc.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Authors:     Alexandre Cassen, <acassen@linux-vs.org>
  *              Eric Jarman, <ehj38230@cmsu2.cmsu.edu>
  *		Bradley Baetz, <bradley.baetz@optusnet.com.au>
@@ -22,7 +20,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "check_misc.h"
@@ -109,7 +107,7 @@ misc_check_thread(thread * thread_obj)
 {
 	checker *checker_obj;
 	misc_checker *misc_chk;
-	int status;
+	int status, ret;
 	pid_t pid;
 
 	checker_obj = THREAD_ARG(thread_obj);
@@ -154,8 +152,8 @@ misc_check_thread(thread * thread_obj)
 	closeall(0);
 
 	open("/dev/null", O_RDWR);
-	dup(0);
-	dup(0);
+	ret = dup(0);
+	ret = dup(0);
 
 	status = system_call(misc_chk->path);
 
