@@ -7,8 +7,6 @@
  *              data structure representation the conf file representing
  *              the loadbalanced server pool.
  *  
- * Version:     $Id: check_parser.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- * 
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *              
  *              This program is distributed in the hope that it will be useful,
@@ -21,7 +19,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "check_parser.h"
@@ -33,6 +31,7 @@
 #include "parser.h"
 #include "memory.h"
 #include "utils.h"
+#include "ipwrapper.h"
 
 /* SSL handlers */
 static void
@@ -99,21 +98,12 @@ lbkind_handler(vector strvec)
 	virtual_server *vs = LIST_TAIL_DATA(check_data->vs);
 	char *str = VECTOR_SLOT(strvec, 1);
 
-#ifdef _KRNL_2_2_
-	if (!strcmp(str, "NAT"))
-		vs->loadbalancing_kind = 0;
-	else if (!strcmp(str, "DR"))
-		vs->loadbalancing_kind = IP_MASQ_F_VS_DROUTE;
-	else if (!strcmp(str, "TUN"))
-		vs->loadbalancing_kind = IP_MASQ_F_VS_TUNNEL;
-#else
 	if (!strcmp(str, "NAT"))
 		vs->loadbalancing_kind = IP_VS_CONN_F_MASQ;
 	else if (!strcmp(str, "DR"))
 		vs->loadbalancing_kind = IP_VS_CONN_F_DROUTE;
 	else if (!strcmp(str, "TUN"))
 		vs->loadbalancing_kind = IP_VS_CONN_F_TUNNEL;
-#endif
 	else
 		log_message(LOG_INFO, "PARSER : unknown [%s] routing method.", str);
 }
@@ -224,6 +214,7 @@ alpha_handler(vector strvec)
 {
 	virtual_server *vs = LIST_TAIL_DATA(check_data->vs);
 	vs->alpha = 1;
+	vs->quorum_state = DOWN;
 }
 static void
 omega_handler(vector strvec)
