@@ -6,8 +6,6 @@
  * Part:        IPVS Kernel wrapper. Use setsockopt call to add/remove
  *              server to/from the loadbalanced server pool.
  *  
- * Version:     $Id: ipvswrapper.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- * 
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *              
  *               This program is distributed in the hope that it will be useful,
@@ -20,7 +18,7 @@
  *               as published by the Free Software Foundation; either version
  *               2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "ipvswrapper.h"
@@ -50,116 +48,7 @@ ipvs_get_group_by_name(char *gname, list l)
 	return NULL;
 }
 
-#ifdef _KRNL_2_2_		/* KERNEL 2.2 IPVS handling */
-
-/* Simple fake func for compatibility */
-int
-ipvs_start(void)
-{
-	return IPVS_SUCCESS;
-}
-void
-ipvs_stop(void)
-{
-}
-
-int
-ipvs_syncd_cmd(int cmd, char *ifname, int state, int syncid)
-{
-	log_message(LOG_INFO, "IPVS : Sync daemon not supported on kernel v2.2");
-	return IPVS_ERROR;
-}
-
-int
-ipvs_cmd(int cmd, list vs_group, virtual_server * vs, real_server * rs)
-{
-	struct ip_masq_ctl ctl;
-	int result = 0;
-	int sockfd;
-
-	memset(&ctl, 0, sizeof (struct ip_masq_ctl));
-
-	ctl.m_target = IP_MASQ_TARGET_VS;
-	ctl.m_cmd = cmd;
-	strncpy(ctl.m_tname, vs->sched, IP_MASQ_TNAME_MAX);
-	ctl.u.vs_user.weight = -1;
-	ctl.u.vs_user.masq_flags = vs->loadbalancing_kind;
-	ctl.u.vs_user.netmask = ((u_int32_t) 0xffffffff);
-	ctl.u.vs_user.protocol = vs->service_type;
-
-	if (!parse_timeout(vs->timeout_persistence, &ctl.u.vs_user.timeout))
-		log_message(LOG_INFO,
-		       "IPVS : Virtual service [%s:%d] illegal timeout.",
-		       inet_ntop2(SVR_IP(vs))
-		       , ntohs(SVR_PORT(vs)));
-	if (ctl.u.vs_user.timeout != 0 || vs->granularity_persistence)
-		ctl.u.vs_user.vs_flags = IP_VS_SVC_F_PERSISTENT;
-
-	/* VS specific */
-	if (vs->vfwmark) {
-		ctl.u.vs_user.vfwmark = vs->vfwmark;
-	} else {
-		ctl.u.vs_user.vaddr = SVR_IP(vs);
-		ctl.u.vs_user.vport = SVR_PORT(vs);
-	}
-
-	if (ctl.m_cmd == IP_MASQ_CMD_ADD || ctl.m_cmd == IP_MASQ_CMD_DEL)
-		if (vs->granularity_persistence)
-			ctl.u.vs_user.netmask = vs->granularity_persistence;
-
-	/* SVR specific */
-	if (ctl.m_cmd == IP_MASQ_CMD_ADD_DEST
-	    || ctl.m_cmd == IP_MASQ_CMD_DEL_DEST
-	    || ctl.m_cmd == IP_MASQ_CMD_SET_DEST) {
-		ctl.u.vs_user.weight = rs->weight;
-		ctl.u.vs_user.daddr = SVR_IP(rs);
-		ctl.u.vs_user.dport = SVR_PORT(rs);
-	}
-
-	/* Does the service use inhibit flag ? */
-	if (ctl.m_cmd == IP_MASQ_CMD_DEL_DEST && rs->inhibit) {
-		ctl.m_cmd = IP_MASQ_CMD_SET_DEST;
-		ctl.u.vs_user.weight = 0;
-	}
-	if (ctl.m_cmd == IP_MASQ_CMD_ADD_DEST && rs->inhibit && !rs->alive)
-		ctl.m_cmd = IP_MASQ_CMD_SET_DEST;
-
-	sockfd = socket(AF_INET, SOCK_RAW, IPPROTO_RAW);
-	if (sockfd == -1) {
-		log_message(LOG_INFO,
-		       "IPVS : Can not initialize SOCK_RAW descriptor.");
-		return IPVS_ERROR;
-	}
-
-	result =
-	    setsockopt(sockfd, IPPROTO_IP, IP_FW_MASQ_CTL, (char *) &ctl,
-		       sizeof (ctl));
-
-	if (errno == ESRCH) {
-		log_message(LOG_INFO, "IPVS : Virtual service [%s:%d] not defined.",
-		       inet_ntop2(SVR_IP(vs))
-		       , ntohs(SVR_PORT(vs)));
-		close(sockfd);
-		return IPVS_ERROR;
-	} else if (errno == EEXIST) {
-		if (rs)
-			log_message(LOG_INFO,
-			       "IPVS : Destination already exists [%s:%d].",
-			       inet_ntop2(SVR_IP(rs))
-			       , ntohs(SVR_PORT(rs)));
-	} else if (errno == ENOENT) {
-		if (rs)
-			log_message(LOG_INFO, "IPVS : No such destination [%s:%d].",
-			       inet_ntop2(SVR_IP(rs))
-			       , ntohs(SVR_PORT(rs)));
-	}
-
-	close(sockfd);
-	return IPVS_SUCCESS;
-}
-
-
-#elif _KRNL_2_4_			/* KERNEL 2.4 IPVS handling */
+#ifdef _KRNL_2_4_			/* KERNEL 2.4 IPVS handling */
 
 /* Global module def IPVS rules */
 static struct ip_vs_rule_user *urule;
@@ -196,7 +85,12 @@ ipvs_stop(void)
 static int
 ipvs_talk(int cmd)
 {
-	if (ipvs_command(cmd, urule))
+	int result;
+	if (result = ipvs_command(cmd, urule))
+		if ((cmd == IP_VS_SO_SET_EDITDEST) &&
+		    (errno == ENOENT))
+			result = ipvs_command(IP_VS_SO_SET_ADDDEST, urule);
+	if (result)
 		log_message(LOG_INFO, "IPVS : %s", ipvs_strerror(errno));
 	return IPVS_SUCCESS;
 }
@@ -499,7 +393,9 @@ ipvs_talk(int cmd)
 			result = ipvs_del_dest(srule, drule);
 			break;
 		case IP_VS_SO_SET_EDITDEST:
-			result = ipvs_update_dest(srule, drule);
+			if ((result = ipvs_update_dest(srule, drule)) &&
+			    (errno == ENOENT))
+				result = ipvs_add_dest(srule, drule);
 			break;
 	}
 
