@@ -5,8 +5,6 @@
  *
  * Part:        Manipulation functions for IPVS & IPFW wrappers.
  *
- * Version:     $Id: ipwrapper.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "ipwrapper.h"
@@ -94,14 +92,6 @@ clear_service_rs(list vs_group, virtual_server * vs, list l)
 				notify_exec(vs->quorum_down);
 			}
 		}
-#ifdef _KRNL_2_2_
-		/* if we have a /32 mask, we create one nat rules per
-		 * realserver.
-		 */
-		if (vs->nat_mask == HOST_NETMASK)
-			if (!ipfw_cmd(IP_FW_CMD_DEL, vs, rs))
-				return 0;
-#endif
 	}
 	return 1;
 }
@@ -145,11 +135,6 @@ clear_services(void)
 		rs = ELEMENT_DATA(LIST_HEAD(vs->rs));
 		if (!clear_service_vs(check_data->vs_group, vs))
 			return 0;
-#ifdef _KRNL_2_2_
-		if (vs->nat_mask != HOST_NETMASK)
-			if (!ipfw_cmd(IP_FW_CMD_DEL, vs, rs))
-				return 0;
-#endif
 	}
 	return 1;
 }
@@ -182,14 +167,6 @@ init_service_rs(virtual_server * vs)
 				return 0;
 			SET_ALIVE(rs);
 		}
-#ifdef _KRNL_2_2_
-		/* if we have a /32 mask, we create one nat rules per
-		 * realserver.
-		 */
-		if (vs->nat_mask == HOST_NETMASK)
-			if (!ipfw_cmd(IP_FW_CMD_ADD, vs, rs))
-				return 0;
-#endif
 	}
 
 	return 1;
@@ -208,9 +185,12 @@ init_service_vs(virtual_server * vs)
 	}
 
 	/* Processing real server queue */
-	if (!LIST_ISEMPTY(vs->rs))
+	if (!LIST_ISEMPTY(vs->rs)) {
+		if (vs->alpha)
+			vs->quorum_state = DOWN;
 		if (!init_service_rs(vs))
 			return 0;
+	}
 	return 1;
 }
 
@@ -221,25 +201,42 @@ init_services(void)
 	element e;
 	list l = check_data->vs;
 	virtual_server *vs;
-	real_server *rs;
 
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vs = ELEMENT_DATA(e);
-		rs = ELEMENT_DATA(LIST_HEAD(vs->rs));
 		if (!init_service_vs(vs))
 			return 0;
-#ifdef _KRNL_2_2_
-		/* work if all realserver ip address are in the
-		 * same network (it is assumed).
-		 */
-		if (vs->nat_mask != HOST_NETMASK)
-			if (!ipfw_cmd(IP_FW_CMD_ADD, vs, rs))
-				return 0;
-#endif
 	}
 	return 1;
 }
 
+/* add or remove _alive_ real servers from a virtual server */
+void
+perform_quorum_state(virtual_server *vs, int add)
+{
+	element e;
+	real_server *rs;
+	char vsip[16];
+	if (LIST_ISEMPTY(vs->rs))
+		return;
+	log_message(LOG_INFO,
+	       "%s the pool for VS [%s:%d]"
+	       , add?"Adding alive servers to":"Removing alive servers from"
+	       , (vs->vsgname) ? vs->vsgname : inet_ntoa2(SVR_IP(vs), vsip)
+	       , ntohs(SVR_PORT(vs)));
+	for (e = LIST_HEAD(vs->rs); e; ELEMENT_NEXT(e)) {
+		rs = ELEMENT_DATA(e);
+		if (!ISALIVE(rs)) /* We only handle alive servers */
+			continue;
+		if (!(add ^ rs->set)) /* Already done */
+			continue;
+		if (add) rs->alive = 0;
+		ipvs_cmd(add?LVS_CMD_ADD_DEST:LVS_CMD_DEL_DEST,
+			 check_data->vs_group, vs, rs);
+		rs->alive = 1;
+	}
+}
+
 /* manipulate add/remove rs according to alive state */
 void
 perform_svr_state(int alive, virtual_server * vs, real_server * rs)
@@ -259,7 +256,10 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 		 * we remove it from the vs pool.
 		 */
 		if (vs->s_svr) {
-			if (ISALIVE(vs->s_svr)) {
+			if (ISALIVE(vs->s_svr) &&
+			    (vs->quorum_state == UP ||
+			     (weigh_live_realservers(vs) + rs->weight >=
+			      vs->quorum + vs->hysteresis))) {
 				log_message(LOG_INFO,
 				       "Removing sorry server [%s:%d] from VS [%s:%d]",
 				       inet_ntoa2(SVR_IP(vs->s_svr), rsip)
@@ -272,9 +272,6 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 					 , vs
 					 , vs->s_svr);
 				vs->s_svr->alive = 0;
-#ifdef _KRNL_2_2_
-				ipfw_cmd(IP_FW_CMD_DEL, vs, vs->s_svr);
-#endif
 			}
 		}
 
@@ -284,7 +281,10 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 		       , ntohs(SVR_PORT(rs))
 		       , (vs->vsgname) ? vs->vsgname : inet_ntoa2(SVR_IP(vs), vsip)
 		       , ntohs(SVR_PORT(vs)));
-		ipvs_cmd(LVS_CMD_ADD_DEST, check_data->vs_group, vs, rs);
+		/* Add only if we have quorum or no sorry server */
+		if (vs->quorum_state == UP || !vs->s_svr || !ISALIVE(vs->s_svr)) {
+			ipvs_cmd(LVS_CMD_ADD_DEST, check_data->vs_group, vs, rs);
+		}
 		rs->alive = alive;
 		if (rs->notify_up) {
 			log_message(LOG_INFO, "Executing [%s] for service [%s:%d]"
@@ -307,6 +307,9 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 				    , weigh_live_realservers(vs)
 				    , (vs->vsgname) ? vs->vsgname : inet_ntoa2(SVR_IP(vs), vsip)
 				    , ntohs(SVR_PORT(vs)));
+			if (vs->s_svr)
+				/* Adding back alive real servers */
+				perform_quorum_state(vs, 1);
 			if (vs->quorum_up) {
 				log_message(LOG_INFO, "Executing [%s] for VS [%s:%d]"
 					    , vs->quorum_up
@@ -315,10 +318,6 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 				notify_exec(vs->quorum_up);
 			}
 		}
-#ifdef _KRNL_2_2_
-		if (vs->nat_mask == HOST_NETMASK)
-			ipfw_cmd(IP_FW_CMD_ADD, vs, rs);
-#endif
 		return;
 	}
 
@@ -332,7 +331,10 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 		       , ntohs(SVR_PORT(vs)));
 
 		/* server is down, it is removed from the LVS realserver pool */
-		ipvs_cmd(LVS_CMD_DEL_DEST, check_data->vs_group, vs, rs);
+		/* Remove only if we have quorum or no sorry server */
+		if (vs->quorum_state == UP || !vs->s_svr || !ISALIVE(vs->s_svr)) {
+			ipvs_cmd(LVS_CMD_DEL_DEST, check_data->vs_group, vs, rs);
+		}
 		rs->alive = alive;
 		if (rs->notify_down) {
 			log_message(LOG_INFO, "Executing [%s] for service [%s:%d]"
@@ -345,12 +347,6 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 			notify_exec(rs->notify_down);
 		}
 
-#ifdef _KRNL_2_2_
-		if (vs->nat_mask == HOST_NETMASK)
-			ipfw_cmd(IP_FW_CMD_DEL, vs, rs);
-#endif
-
-
 		/* If we have just lost quorum for the VS, we need to consider
 		 * VS notify_down and sorry_server cases
 		 */
@@ -383,9 +379,8 @@ perform_svr_state(int alive, virtual_server * vs, real_server * rs)
 				ipvs_cmd(LVS_CMD_ADD_DEST, check_data->vs_group, vs, vs->s_svr);
 				vs->s_svr->alive = 1;
 
- #ifdef _KRNL_2_2_
-				ipfw_cmd(IP_FW_CMD_ADD, vs, vs->s_svr);
- #endif
+				/* Remove remaining alive real servers */
+				perform_quorum_state(vs, 0);
 			}
 		}
 	}
@@ -563,13 +558,7 @@ vs_exist(virtual_server * old_vs)
 		vs = ELEMENT_DATA(e);
 		if (VS_ISEQ(old_vs, vs)) {
 			/* Check if group exist */
-			if ((vs->vsgname && !old_vs->vsgname) ||
-			    (!vs->vsgname && old_vs->vsgname))
-				return 0;
-
 			if (vs->vsgname) {
-				if (strcmp(vs->vsgname, old_vs->vsgname) != 0)
-					return 0;
 				vsg = ipvs_get_group_by_name(old_vs->vsgname,
 							    check_data->vs_group);
 				if (!vsg)
