@@ -5,8 +5,6 @@
  *
  * Part:        Main program structure.
  *
- * Version:     $Id: main.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include <syslog.h>
@@ -32,6 +30,7 @@ pid_t
 xdaemon(int nochdir, int noclose, int exitflag)
 {
 	pid_t pid;
+	int ret;
 
 	/* In case of fork is error. */
 	pid = fork();
@@ -57,7 +56,7 @@ xdaemon(int nochdir, int noclose, int exitflag)
 
 	/* Change directory to root. */
 	if (!nochdir)
-		chdir("/");
+		ret = chdir("/");
 
 	/* File descriptor close. */
 	if (!noclose) {
