@@ -5,8 +5,6 @@
  *
  * Part:        pidfile utility.
  *
- * Version:     $Id: pidfile.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "logger.h"
@@ -57,12 +55,13 @@ process_running(char *pid_file)
 {
 	FILE *pidfile = fopen(pid_file, "r");
 	pid_t pid;
+	int ret;
 
 	/* No pidfile */
 	if (!pidfile)
 		return 0;
 
-	fscanf(pidfile, "%d", &pid);
+	ret = fscanf(pidfile, "%d", &pid);
 	fclose(pidfile);
 
 	/* If no process is attached to pidfile, remove it */
@@ -90,17 +89,3 @@ keepalived_running(int mode)
 		return 1;
 	return 0;
 }
-
-/* Return VRRP child process state */
-int
-vrrp_running(void)
-{
-	return process_running(vrrp_pidfile);
-}
-
-/* Return VRRP child process state */
-int
-checkers_running(void)
-{
-	return process_running(checkers_pidfile);
-}
