@@ -5,8 +5,6 @@
  *
  * Part:        Healthcheckers dynamic data structure definition.
  *
- * Version:     $Id: check_data.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _CHECK_DATA_H
@@ -34,16 +32,10 @@
 #include <openssl/ssl.h>
 
 #ifdef _WITH_LVS_
-#ifdef _KRNL_2_2_
-#include <linux/ip_masq.h>
-#include <net/ip_masq.h>
-#define SCHED_MAX_LENGTH IP_MASQ_TNAME_MAX
+  #define SCHED_MAX_LENGTH IP_VS_SCHEDNAME_MAXLEN
+  #include <net/ip_vs.h>
 #else
-#define SCHED_MAX_LENGTH IP_VS_SCHEDNAME_MAXLEN
-#endif
-#include <net/ip_vs.h>
-#else
-#define SCHED_MAX_LENGTH   1
+  #define SCHED_MAX_LENGTH   1
 #endif
 
 /* local includes */
@@ -156,7 +148,10 @@ typedef struct _check_conf_data {
 			 (X)->nat_mask                == (Y)->nat_mask &&		\
 			 (X)->granularity_persistence == (Y)->granularity_persistence &&\
 			 !strcmp((X)->sched, (Y)->sched) &&				\
-			 !strcmp((X)->timeout_persistence, (Y)->timeout_persistence))
+			 !strcmp((X)->timeout_persistence, (Y)->timeout_persistence) && \
+			 (((X)->vsgname && (Y)->vsgname &&				\
+			   !strcmp((X)->vsgname, (Y)->vsgname)) || 			\
+			  (!(X)->vsgname && !(Y)->vsgname)))
 
 #define VSGE_ISEQ(X,Y)	((X)->addr_ip   == (Y)->addr_ip &&	\
 			 (X)->range     == (Y)->range &&	\
