@@ -5,8 +5,6 @@
  *
  * Part:        ipvswrapper.c include file.
  *
- * Version:     $Id: ipvswrapper.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _IPVSWRAPPER_H
@@ -40,10 +38,7 @@
 #include <sys/wait.h>
 
 #ifdef _WITH_LVS_
-#ifdef _KRNL_2_2_
-  #include <linux/ip_fw.h>
-  #include <net/ip_masq.h>
-#elif _KRNL_2_4_
+#ifdef _KRNL_2_4_
   #include "../libipvs-2.4/libipvs.h"
 #elif _KRNL_2_6_
   #include "../libipvs-2.6/libipvs.h"
