@@ -5,8 +5,6 @@
  *
  * Part:        ipwrapper.c include file.
  *
- * Version:     $Id: ipwrapper.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _IPWRAPPER_H
@@ -44,19 +42,11 @@
 #define DOWN 0
 
 /* LVS command set by kernel */
-#ifdef _KRNL_2_2_
-#define LVS_CMD_ADD		IP_MASQ_CMD_ADD
-#define LVS_CMD_DEL		IP_MASQ_CMD_DEL
-#define LVS_CMD_ADD_DEST	IP_MASQ_CMD_ADD_DEST
-#define LVS_CMD_DEL_DEST	IP_MASQ_CMD_DEL_DEST
-#define LVS_CMD_EDIT_DEST	IP_MASQ_CMD_SET_DEST
-#else
 #define LVS_CMD_ADD		IP_VS_SO_SET_ADD
 #define LVS_CMD_DEL		IP_VS_SO_SET_DEL
 #define LVS_CMD_ADD_DEST	IP_VS_SO_SET_ADDDEST
 #define LVS_CMD_DEL_DEST	IP_VS_SO_SET_DELDEST
 #define LVS_CMD_EDIT_DEST	IP_VS_SO_SET_EDITDEST
-#endif
 
 /* prototypes */
 extern void perform_svr_state(int alive, virtual_server * vs, real_server * rs);
@@ -68,7 +58,4 @@ extern int init_services(void);
 extern int clear_services(void);
 extern int clear_diff_services(void);
 
-//extern int ipvs_cmd(int cmd, virtual_server * vserver, real_server * rserver);
-extern int ipfw_cmd(int cmd, virtual_server * vserver, real_server * rserver);
-
 #endif
