@@ -5,8 +5,6 @@
  *
  * Part:        pidfile.c include file.
  *
- * Version:     $Id: pidfile.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _PIDFILE_H
@@ -43,7 +41,5 @@
 extern int pidfile_write(char *pid_file, int pid);
 extern void pidfile_rm(char *pid_file);
 extern int keepalived_running(int mode);
-extern int vrrp_running(void);
-extern int checkers_running(void);
 
 #endif
