@@ -8,8 +8,6 @@
  *              master fails, a backup server takes over.
  *              The original implementation has been made by jerome etienne.
  *
- * Version:     $Id: vrrp.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful, 
@@ -22,7 +20,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 /* local include */
@@ -788,6 +786,7 @@ vrrp_state_master_rx(vrrp_rt * vrrp, char *buf, int buflen)
 	if (vrrp->wantstate == VRRP_STATE_GOTO_FAULT) {
 		vrrp->ms_down_timer = 3 * vrrp->adver_int + VRRP_TIMER_SKEW(vrrp);
 		vrrp->state = VRRP_STATE_FAULT;
+		notify_instance_exec(vrrp, VRRP_STATE_FAULT);
 		return 1;
 	}
 
@@ -882,7 +881,8 @@ vrrp_state_fault_rx(vrrp_rt * vrrp, char *buf, int buflen)
 		return 0;
 	} else if (vrrp->effective_priority > hd->priority ||
 		   hd->priority == VRRP_PRIO_OWNER)
-		return 1;
+		if (!vrrp->nopreempt)
+			return 1;
 
 	return 0;
 }
@@ -1108,6 +1108,7 @@ reset_vrrp_state(vrrp_rt * old_vrrp)
 	vrrp->state = old_vrrp->state;
 	vrrp->init_state = old_vrrp->state;
 	vrrp->wantstate = old_vrrp->state;
+	vrrp->effective_priority = old_vrrp->effective_priority;
 	memcpy(vrrp->ipsecah_counter, old_vrrp->ipsecah_counter, sizeof(seq_counter));
 
 #ifdef _HAVE_IPVS_SYNCD_
@@ -1185,13 +1186,12 @@ clear_diff_script(void)
 
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		vscript = ELEMENT_DATA(e);
-		if (vscript->result == VRRP_SCRIPT_STATUS_GOOD) {
+		if (vscript->result >= vscript->rise) {
 			nvscript = find_script_by_name(vscript->sname);
 			if (nvscript) {
 				log_message(LOG_INFO, "VRRP_Script(%s) considered successful on reload",
 					   nvscript->sname);
 				nvscript->result = VRRP_SCRIPT_STATUS_INIT_GOOD;
-				break;
 			}
 		}
 	}
