@@ -5,8 +5,6 @@
  *
  * Part:        Interfaces manipulation.
  *
- * Version:     $Id: vrrp_if.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 /* global include */
@@ -49,6 +47,7 @@ typedef __uint8_t u8;
 
 /* local include */
 #include "scheduler.h"
+#include "global_data.h"
 #include "vrrp_data.h"
 #include "vrrp.h"
 #include "vrrp_if.h"
@@ -321,7 +320,6 @@ if_add_queue(interface * ifp)
 	list_add(if_queue, ifp);
 }
 
-#ifndef _WITH_LINKWATCH_
 static int
 if_linkbeat_refresh_thread(thread * thread_obj)
 {
@@ -375,11 +373,14 @@ init_if_linkbeat(void)
 int
 if_linkbeat(const interface * ifp)
 {
+	if (!data->linkbeat_use_polling)
+		return 1;
+
 	if (IF_MII_SUPPORTED(ifp) || IF_ETHTOOL_SUPPORTED(ifp))
 		return IF_LINKBEAT(ifp);
+
 	return 1;
 }
-#endif
 
 /* Interface queue helpers*/
 void
@@ -397,12 +398,17 @@ init_interface_queue(void)
 	init_if_queue();
 //	dump_list(if_queue);
 	netlink_interface_lookup();
-#ifdef _WITH_LINKWATCH_
-	  log_message(LOG_INFO, "Using LinkWatch kernel netlink reflector...");
-#else
-	  log_message(LOG_INFO, "Using MII-BMSR NIC polling thread...");
-	  init_if_linkbeat();
-#endif
+}
+
+void
+init_interface_linkbeat(void)
+{
+	if (data->linkbeat_use_polling) {
+		log_message(LOG_INFO, "Using MII-BMSR NIC polling thread...");
+		init_if_linkbeat();
+	} else {
+		log_message(LOG_INFO, "Using LinkWatch kernel netlink reflector...");
+	}
 }
 
 int
