@@ -5,8 +5,6 @@
  *
  * Part:        NETLINK kernel command channel.
  *
- * Version:     $Id: vrrp_netlink.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 /* global include */
@@ -242,7 +240,7 @@ netlink_scope_a2n(char *scope)
 /* Our netlink parser */
 static int
 netlink_parse_info(int (*filter) (struct sockaddr_nl *, struct nlmsghdr *),
-		   struct nl_handle *nl)
+		   struct nl_handle *nl, struct nlmsghdr *n)
 {
 	int status;
 	int ret = 0;
@@ -304,6 +302,12 @@ netlink_parse_info(int (*filter) (struct sockaddr_nl *, struct nlmsghdr *),
 					       "Netlink: error: message truncated");
 					return -1;
 				}
+
+				if (n && (err->error == -EEXIST) &&
+				    ((n->nlmsg_type == RTM_NEWROUTE) ||
+				     (n->nlmsg_type == RTM_NEWADDR)))
+					return 0;
+
 				log_message(LOG_INFO,
 				       "Netlink: error: %s, type=(%u), seq=%u, pid=%d",
 				       strerror(-err->error),
@@ -314,15 +318,12 @@ netlink_parse_info(int (*filter) (struct sockaddr_nl *, struct nlmsghdr *),
 			}
 
 			/* Skip unsolicited messages from cmd channel */
-			if (nl != &nl_cmd && h->nlmsg_pid == nl_cmd.snl.nl_pid) {
-				log_message(LOG_INFO, "Netlink: skipping nl_cmd msg...");
+			if (nl != &nl_cmd && h->nlmsg_pid == nl_cmd.snl.nl_pid)
 				continue;
-			}
 
 			error = (*filter) (&snl, h);
 			if (error < 0) {
-				log_message(LOG_INFO,
-				       "Netlink: filter function error");
+				log_message(LOG_INFO, "Netlink: filter function error");
 				ret = error;
 			}
 		}
@@ -383,7 +384,7 @@ netlink_talk(struct nl_handle *nl, struct nlmsghdr *n)
 		log_message(LOG_INFO, "Netlink: Warning, couldn't set "
 		       "blocking flag to netlink socket...");
 
-	status = netlink_parse_info(netlink_talk_filter, nl);
+	status = netlink_parse_info(netlink_talk_filter, nl, n);
 
 	/* Restore previous flags */
 	if (ret == 0)
@@ -559,7 +560,7 @@ netlink_interface_lookup(void)
 	/* Set blocking flag */
 	ret = netlink_set_block(&nlh, &flags);
 	if (ret < 0)
-		log_message(LOG_INFO, "Netlink: 1Warning, couldn't set "
+		log_message(LOG_INFO, "Netlink: Warning, couldn't set "
 		       "blocking flag to netlink socket...");
 
 	/* Interface lookup */
@@ -567,7 +568,7 @@ netlink_interface_lookup(void)
 		status = -1;
 		goto end_int;
 	}
-	status = netlink_parse_info(netlink_if_link_filter, &nlh);
+	status = netlink_parse_info(netlink_if_link_filter, &nlh, NULL);
 
 end_int:
 	netlink_close(&nlh);
@@ -596,7 +597,7 @@ netlink_address_lookup(void)
 		status = -1;
 		goto end_addr;
 	}
-	status = netlink_parse_info(netlink_if_address_filter, &nlh);
+	status = netlink_parse_info(netlink_if_address_filter, &nlh, NULL);
 
 end_addr:
 	netlink_close(&nlh);
@@ -669,7 +670,7 @@ kernel_netlink(thread * thread_obj)
 	int status = 0;
 
 	if (thread_obj->type != THREAD_READ_TIMEOUT)
-		status = netlink_parse_info(netlink_broadcast_filter, &nl_kernel);
+		status = netlink_parse_info(netlink_broadcast_filter, &nl_kernel, NULL);
 	thread_add_read(master, kernel_netlink, NULL, nl_kernel.fd,
 			NETLINK_TIMER);
 	return 0;
