@@ -5,8 +5,6 @@
  *
  * Part:        Interface tracking framework.
  *
- * Version:     $Id: vrrp_track.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 /* local include */
@@ -198,7 +196,7 @@ vrrp_script_up(list l)
 
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		tsc = ELEMENT_DATA(e);
-		if (!tsc->weight && tsc->scr->result == VRRP_SCRIPT_STATUS_NONE)
+		if (!tsc->weight && tsc->scr->result < tsc->scr->rise)
 			return 0;
 	}
 
@@ -219,10 +217,10 @@ vrrp_script_weight(list l)
 
 	for (e = LIST_HEAD(l); e; ELEMENT_NEXT(e)) {
 		tsc = ELEMENT_DATA(e);
-		if (tsc->scr->result == VRRP_SCRIPT_STATUS_GOOD) {
+		if (tsc->scr->result >= tsc->scr->rise) {
 			if (tsc->weight > 0)
 				weight += tsc->weight;
-		} else if (tsc->scr->result == VRRP_SCRIPT_STATUS_NONE) {
+		} else if (tsc->scr->result < tsc->scr->rise) {
 			if (tsc->weight < 0)
 				weight += tsc->weight;
 		}
