@@ -5,8 +5,6 @@
  * 
  * Part:        Signals framework.
  *  
- * Version:     $Id: signals.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- * 
  * Author:      Kevin Lindsay, <kevinl@netnation.com>
  *              Alexandre Cassen, <acassen@linux-vs.org>
  *              
@@ -20,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include <signal.h>
@@ -139,19 +137,40 @@ signal_handler_init(void)
 }
 
 void
-signal_handler_destroy(void) {
+signal_wait_handlers(void)
+{
 	struct sigaction sig;
 
 	sig.sa_handler = SIG_DFL;
 	sigemptyset(&sig.sa_mask);
 	sig.sa_flags = 0;
 
-	/* First ensure that no more signals happen, then close pipe */
+	/* Ensure no more pending signals */
 	sigaction(SIGHUP, &sig, NULL);
 	sigaction(SIGINT, &sig, NULL);
 	sigaction(SIGTERM, &sig, NULL);
 	sigaction(SIGCHLD, &sig, NULL);
 
+	/* reset */
+	signal_SIGHUP_v = NULL;
+	signal_SIGINT_v = NULL;
+	signal_SIGTERM_v = NULL;
+	signal_SIGCHLD_v = NULL;
+}
+
+void signal_reset(void)
+{
+	signal_wait_handlers();
+	signal_SIGHUP_handler = NULL;
+	signal_SIGINT_handler = NULL;
+	signal_SIGTERM_handler = NULL;
+	signal_SIGCHLD_handler = NULL;
+}
+
+void
+signal_handler_destroy(void)
+{
+	signal_wait_handlers();
 	close(signal_pipe[1]);
 	close(signal_pipe[0]);
 	signal_pipe[1] = -1;
@@ -159,7 +178,8 @@ signal_handler_destroy(void) {
 }	
 
 int
-signal_rfd(void) {
+signal_rfd(void)
+{
 	return(signal_pipe[0]);
 }
 
@@ -192,4 +212,3 @@ signal_run_callback(void)
 		}	
 	}
 }
-
