@@ -5,8 +5,6 @@
  * 
  * Part:        signals.c include file.
  *  
- * Version:     $Id: signals.h,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- *
  * Author:      Kevin Lindsay, <kevinl@netnation.com>
  *              Alexandre Cassen, <acassen@linux-vs.org>
  *
@@ -20,7 +18,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #ifndef _SIGNALS_H
@@ -32,7 +30,9 @@ extern void *signal_set(int signo, void (*func) (void *, int), void *);
 extern void *signal_ignore(int signo);
 extern void signal_handler_init(void);
 extern void signal_handler_destroy(void);
+extern void signal_reset(void);
 extern void signal_run_callback(void);
+extern void signal_wait_handlers(void);
 
 extern int signal_rfd(void);
 
