@@ -5,8 +5,6 @@
  * 
  * Part:        Vector structure manipulation.
  *  
- * Version:     $Id: vector.c,v 1.1.17 2009/03/05 01:31:12 acassen Exp $
- * 
  * Author:      Alexandre Cassen, <acassen@linux-vs.org>
  *              
  *              This program is distributed in the hope that it will be useful,
@@ -19,7 +17,7 @@
  *              as published by the Free Software Foundation; either version
  *              2 of the License, or (at your option) any later version.
  *
- * Copyright (C) 2001-2009 Alexandre Cassen, <acassen@freebox.fr>
+ * Copyright (C) 2001-2010 Alexandre Cassen, <acassen@freebox.fr>
  */
 
 #include "vector.h"
@@ -59,28 +57,6 @@ vector_insert_slot(vector v, int slot, void *value)
 	v->slot[slot] = value;
 }
 
-/* Del a slot */
-void
-vector_del_slot(vector v, int slot)
-{
-	int i;
-
-	if (!v->allocated)
-		return;
-
-	for (i = slot + 1; i < (v->allocated / VECTOR_DEFAULT_SIZE); i++)
-		v->slot[i - 1] = v->slot[i];
-
-	v->allocated -= VECTOR_DEFAULT_SIZE;
-
-	if (!v->allocated)
-		v->slot = NULL;
-	else
-		v->slot = (void *) MALLOC(sizeof (void *) * v->allocated);
-
-	v = REALLOC(v->slot, sizeof (void *) * v->allocated);
-}
-
 /* Free memory vector allocation */
 void
 vector_free(vector v)
